package X3D::FieldTypes::MFVec3d;

our $VERSION = '0.009';

use X3D::Package 'MFVec3d : X3DArrayField { [] }';

1;
__END__
